import json
import logging

from amqp import RpcClient

# Get an instance of a logger
logger = logging.getLogger(__name__)

class VisaRpcClient(RpcClient):
    def __init__(self, username, password, name='query', exchange='visa_rpc', host='localhost', port=5432):
        RpcClient.__init__(self, host=host, name=name, exchange=exchange, username=username, password=password, port=port)
        self.name = name
        self.declare_method(self.on_response)

    def toMessage(self, alias, command):
        return {'alias': alias, 'command': command}

    def fromMessage(self, response):
        return response['result']

    def alias(self, request):
        logger.info('REMOTE.alias request ' + json.dumps(obj=request, ensure_ascii=False))
        return json.loads(self.call(body=request, method_name='alias'))

    def query(self, alias, command):
        request = self.toMessage(alias, command)
        logger.info('REMOTE.query request ' + json.dumps(obj=request, ensure_ascii=False))
        response = self.call(body=request, method_name='query')
        return self.fromMessage(response);

    def read(self, alias, command):
        request = self.toMessage(alias, command)
        logger.info('REMOTE.read request ' + json.dumps(obj=request, ensure_ascii=False))
        response = self.call(body=request, method_name='read')
        return self.fromMessage(json.loads(response));

    def write(self, alias, command):
        request = self.toMessage(alias, command)

        logger.info('REMOTE.write request ' + json.dumps(obj=request, ensure_ascii=False))
        return self.call(body=request, method_name='write')

    def list(self):
        logger.info('REMOTE.list request ')
        return self.call(method_name='list', body=json.dumps(obj={}, ensure_ascii=False))


import os
from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='hedgehog-station-controller',
    version='2.4.3',
    packages=find_packages(),
    include_package_data=True,
    license='Apache 2.0 License',  # example license
    description='Hedgehog station controller.',
    long_description=README,
    url='https://github.com/lordoftheflies/hedgehog-station-controller/',
    author='lordoftheflies',
    author_email='laszlo.hegedus@cherubits.hu',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 1.10',  # replace "X.Y" as appropriate
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',  # example license
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Database',
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Scientific/Engineering :: Visualization',
        'Topic :: System :: Monitoring',
        'Development Status :: 2 - Pre-Alpha'
    ],
    install_requires=[
        'django',
        'channels',
        'djangorestframework',
        'netifaces',
        'cronlikescheduler',
        'pyyaml',
        'pyusb',
        'pyserial',
        'pyvisa',
        'pyvisa-py',
        'pyvisa-sim',
        'pika',
        'jinja2',
        'numpy',
        'scipy',
        'matplotlib',
        'mpld3'
    ],
    entry_points = {
        'console_scripts': [
            'hedgehog-controller = assetadapter.main:main',
        ]
    }
)